@@ -57,7 +57,7 @@ def get_userinfo_from_external_id(external_id):
     # Call regapp
     BWIDM = BwIdmConnection(CONFIG)
     resp = BWIDM.get ('external-user', 'find', 'externalId', external_id)
-    print (F"RESP: {resp}")
+    logger.debug(F"RESP: {resp}")
     resp_json = safe_resp_conversion(resp)
 
     return resp_json
@@ -84,21 +84,33 @@ def get_username_from_external_id(external_id):
 def get_sshkey_from_external_id (external_id):
     '''get ssh key from an external_id'''
     resp_json = get_userinfo_from_external_id(external_id)
+    # print(json.dumps(resp_json, sort_keys=True, indent=4, separators=(',', ': ')))
+    sshkeys=""
 
     try:
         sshkeys_entry = resp_json['genericStore']['ssh_key']
         sshkeys_store = json.loads(sshkeys_entry)
-        sshkeys=""
+    except json.JSONDecodeError:
+        try:
+            sshkeys_entry = sshkeys_entry.replace("'", '"')
+            sshkeys_store = json.loads(sshkeys_entry)
+        except json.JSONDecodeError:
+            logger.error("Cannot find 'ssh_key' in 'genericStore' response of regApp")
+            s_exit(2)
+
+    try:
+        logger.debug(json.dumps(sshkeys_store, sort_keys=True, indent=4, separators=(',', ': ')))
         for key in sshkeys_store:
             sshkeys = sshkeys +  key['value'].rstrip('\n') + "\n"
         if args.verbose:
             logging.debug(F"just obtained keys: {sshkeys}")
-    except json.JSONDecodeError:
-        logger.error("Cannot find 'ssh_key' in 'genericStore' response of regApp")
-        raise
     except KeyError:
-        return ""
+        logger.error("Cannot find 'ssh_key' in 'genericStore' response of regApp. I tried hard:")
+        logger.error(json.dumps(resp_json, sort_keys=True, indent=4, separators=(',', ': ')))
+        s_exit(3)
+    logger.debug(F"returning: {sshkeys}")
     return sshkeys.rstrip('\n')
+
 def safe_resp_conversion(resp):
     '''Safely convert a response to json'''
     if resp.status_code != 200:
